@@ -292,6 +292,10 @@
 #' For all networks, characters are named (eg. R2-D2, Anakin, Chewbacca)
 #' and the following node attributes are provided where available:
 #' height, mass, hair color, skin color, eye color, birth year, sex, homeworld, and species.
+#' The node attribute 'faction' has also been added,
+#' denoting the faction (eg. Jedi, Rebel Alliance, etc) 
+#' that Star Wars characters belong to in each episode
+#' (coding completed with help of Yichen Shen and Tiphaine Aeby).
 #' Weighted ties represent the number of times characters speak 
 #' within the same scene of the film.
 #' @details
@@ -340,3 +344,56 @@
 #'   ison_friends
 #'   ```
 "ison_friends"
+
+
+# Physicians ####
+
+#' Four multiplex one-mode physician diffusion data (Coleman, Katz, and Menzel, 1966)
+#'
+#' @description
+#'   Ron Burt prepared this data from 
+#'   Coleman, Katz and Menzel's 1966 study on medical innovation. 
+#'   They had collected data from physicians in four towns in Illinois: 
+#'   Peoria, Bloomington, Quincy and Galesburg.
+#'   These four networks are held as separate networks in a list.
+#'   
+#'   Coleman, Katz and Menzel were concerned with the impact of network ties 
+#'   on the physicians' adoption of a new drug, tetracycline. 
+#'   Data on three types of ties were collected in response to three questions:
+#'   
+#'   - advice: "When you need information or advice about questions of therapy 
+#'   where do you usually turn?" 
+#'   - discussion: "And who are the three or four physicians with whom you most often find yourself 
+#'   discussing cases or therapy in the course of an ordinary week – last week for instance?" 
+#'   - friendship: "Would you tell me the first names of your three friends 
+#'   whom you see most often socially?"
+#'   
+#'   Additional questions and records of prescriptions provided additional information: 
+#'   - recorded date of tetracycline `adoption` date
+#'   - years in `practice` 
+#'   (note that these are `{messydates}`-compatible dates)
+#'   - `conferences` attended 
+#'   (those that attended "Specialty" conferences presumably also attended "General" conferences)
+#'   - regular subscriptions to medical `journals`
+#'   - `free_time` spent associating with doctors
+#'   - `discussions` on medical matters when with other doctors sociallyy
+#'   - memberships in `clubs` with other doctores
+#'   - number of top 3 `friends` that are doctors
+#'   - time practicing in current `community`
+#'   - `patients` load (ordinal)
+#'   - physical `proximity` to other physicians (in building/sharing office)
+#'   - medical `specialty` (GP/Internist/Pediatrician/Other)
+#' @docType data
+#' @keywords datasets
+#' @name ison_physicians
+#' @usage data(ison_physicians)
+#' @references
+#'   Coleman, James, Elihu Katz, and Herbert Menzel. 1966.
+#'   \emph{Medical innovation: A diffusion study}.
+#'   Indianapolis: The Bobbs-Merrill Company.
+#' @source `{networkdata}`
+#' @format
+#'   ```{r, echo = FALSE}
+#'   ison_physicians
+#'   ```
+"ison_physicians"
