@@ -175,7 +175,6 @@ to_waves <- function(.data, attribute = "wave", panels = NULL) UseMethod("to_wav
 #' @importFrom tidygraph to_subgraph as_tbl_graph
 #' @export
 to_waves.tbl_graph <- function(.data, attribute = "wave", panels = NULL) {
-  
   wp <- unique(tie_attribute(.data, attribute))
   if(!is.null(panels))
     wp <- intersect(panels, wp)
@@ -201,17 +200,33 @@ to_waves.igraph <- function(.data, attribute = "wave", panels = NULL) {
 #' @export
 to_waves.data.frame <- function(.data, attribute = "wave", panels = NULL) {
   wp <- unique(tie_attribute(.data, attribute))
-  if(!is.null(panels))
-    wp <- intersect(panels, wp)
+  if(!is.null(panels)) wp <- intersect(panels, wp)
   if(length(wp)>1){
     out <- lapply(wp, function(l) .data[,attribute == l])
     names(out) <- wp
-  } else if(length(wp)>1){
+  } else if(length(wp)>1) {
     out <- .data[,attribute == wp]
   }
   out
 }
 
+#' @export
+to_waves.diff_model <- function(.data, attribute = "t", panels = NULL) {
+  if(!is.null(panels)) .data <- .data[.data[[attribute]] %in% panels,]
+  if (length(unique(.data[["n"]])) > 1)
+    stop("Please make sure diffusion has the same number of nodes for all time points.")
+  diffusion <- as_tidygraph(.data)
+  out <- list()
+  for (k in .data[[attribute]]) {
+    out[[paste0("Time: ", k)]] <- diffusion %>%
+      add_node_attribute("Infected", c(rep("Recovered", .data$R[k + 1]),
+                                       rep("Infected", .data$I[k + 1]),
+                                       rep("Exposed", .data$E[k + 1]),
+                                       rep("Susceptible", .data$S[k + 1])))
+  }
+  out
+}
+
 #' @describeIn split Returns a list of a network
 #'   with some continuous time variable at some time slice(s).
 #' @param attribute One or two attributes used to slice data.
